@@ -4,7 +4,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Sioftware Foundation; either version 2 of the License, or
 # any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -17,10 +17,75 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-### DSC - Data Stream Clusterer interface
-DSC <- function(...) stop("DSC is an abstract class and cannot be instantiated!")
+#' Data Stream Clusterer Base Classes
+#'
+#' Abstract base classes for all DSC (Data Stream Clusterer) and DSC_R classes.
+#' Concrete implementations are functions starting with `DSC_` (R Studio use auto-completion with Tab to select one).
+#'
+#' The `DSC} and `DSC_R` classes cannot be instantiated (calling
+#' `DSC()` or `DSC_R()` produces only a message listing the available implementations),
+#' but they serve as a base
+#' class from which other DSC classes inherit.
+#'
+#' Class `DSC` provides several generic functions that can operate on all
+#' DSC subclasses. See Functions section below.
+#' Additional, separately documented functions are:
+#'
+#' * [update] Add new data points from a stream to a clustering.
+#' * [plot] function is also provides for `DSC`.
+#' * [get_assignment] Find out what cluster new data points would be assigned to.
+#'
+#' `get_centers` and `get_weights` are typically overwritten by
+#' subclasses of `DSC`. `DSC_R` provides these functions for R-based
+#' DSC implementations.
+#'
+#' Since `DSC` objects often contain external pointers, regular saving and
+#' reading operations will fail. Use [saveDSC] and [readDSC]
+#' which will serialize the objects first appropriately.
+#'
+#' @aliases DSC DSC_R
+#' @param x a DSC object.
+#' @param type Return weights of micro- or macro-clusters in x.  Auto uses the
+#' class of x to decide.
+#' @param scale a range (from, to) to scale the weights.  Returns by default
+#' the raw weights.
+#' @param ... further parameter
+#' @author Michael Hahsler
+#' @seealso [DSC_Micro], [DSC_Macro], [animate_cluster], [update],
+#' [evaluate], [get_assignment],
+#' [microToMacro],
+#' [plot], [prune_clusters],
+#' [recluster], [readDSC], [saveDSC]
+#' @export DSC
+#' @examples
+#'
+#' DSC()
+#'
+#' stream <- DSD_Gaussians(k=3, d=2)
+#' dstream <- DSC_DStream(gridsize=.1)
+#' update(dstream, stream, 500)
+#' dstream
+#'
+#' # get micro-cluster centers
+#' get_centers(dstream)
+#'
+#' # get the number of clusters
+#' nclusters(dstream)
+#'
+#' # get the micro-cluster weights
+#' get_weights(dstream)
+#'
+#' # D-Stream also has macro-clusters
+#' get_weights(dstream, type="macro")
+#'
+#'
+DSC<- abstract_class_generator("DSC")
 
 ### all DSC classes have these interface methods
+
+
+#' @describeIn DSC Gets the cluster centers (micro- or macro-clusters) from a DSC object.
+#' @export get_centers
 get_centers <- function(x, type = c("auto", "micro", "macro"), ...)
   UseMethod("get_centers")
 get_centers.default <- function(x, type = c("auto", "micro", "macro"), ...) {
@@ -28,7 +93,8 @@ get_centers.default <- function(x, type = c("auto", "micro", "macro"), ...) {
     paste(class(x), collapse=", ")))
 }
 
-### get MC weights. In case it is not implemented it returns 1s
+#' @describeIn DSC Get the weights of the clusters in the DSC (returns 1s if not implemented by the clusterer)
+#' @export get_weights
 get_weights <- function(x, type=c("auto", "micro", "macro"), scale=NULL, ...)
   UseMethod("get_weights")
 get_weights.default <- function(x, type=c("auto", "micro", "macro"),
@@ -47,30 +113,38 @@ get_weights.default <- function(x, type=c("auto", "micro", "macro"),
 #####################################################################3
 
 ### make a deep copy of the
+
+
+#' @describeIn DSC Create a Deep Copy of a DSC Object that contain reference classes (e.g., Java data structures for MOA).
+#' @export get_copy
 get_copy <- function(x) UseMethod("get_copy")
 get_copy.default <- function(x, ...) {
   stop(gettextf("get_copy not implemented for class '%s'.",
     paste(class(x), collapse=", ")))
 }
 
+#' @describeIn DSC Get micro-clusters if the object is a `DSC_Micro`.
 get_microclusters <- function(x, ...) UseMethod("get_microclusters")
 get_microclusters.DSC <- function(x, ...) {
   stop(gettextf("No micro-clusters available for class '%s'.",
     paste(class(x), collapse=", ")))
 }
 
+#' @describeIn DSC Get micro-clusters if the the object is a `DSC_Macro`.
 get_macroclusters <- function(x, ...) UseMethod("get_macroclusters")
 get_macroclusters.DSC <- function(x, ...) {
   stop(gettextf("No macro-clusters available for class '%s'.",
     paste(class(x), collapse=", ")))
 }
 
+#' @describeIn DSC Get micro-cluster weights if the object is a `DSC_Micro`.
 get_microweights <- function(x, ...) UseMethod("get_microweights")
 get_microweights.DSC <- function(x, ...) {
   stop(gettextf("No weights for micro-clusters available for class '%s'.",
     paste(class(x), collapse=", ")))
 }
 
+#' @describeIn DSC Get macro-cluster weights if the object is a `DSC_Macro`.
 get_macroweights <- function(x, ...) UseMethod("get_macroweights")
 get_macroweights.DSC <- function(x, ...) {
   stop(gettextf("No weights for macro-clusters available for class '%s'.",
@@ -78,7 +152,8 @@ get_macroweights.DSC <- function(x, ...) {
 }
 
 
-### derived functions, plot and print
+#' @describeIn DSC Returns the number of micro-clusters from the DSC object.
+#' @export nclusters
 nclusters <- function(x, type=c("auto", "micro", "macro"), ...)
   UseMethod("nclusters")
 
@@ -86,7 +161,6 @@ nclusters.DSC <- function(x, type=c("auto", "micro", "macro"), ...) {
   nrow(get_centers(x, type=type, ...))
 }
 
-
 print.DSC <- function(x, ...) {
   cat(.line_break(paste(x$description)))
   cat("Class:", paste(class(x), collapse=", "), "\n")
@@ -98,7 +172,59 @@ print.DSC <- function(x, ...) {
 
 summary.DSC <- function(object, ...) print(object)
 
-#plot.DSC will call super question.
+#' Plotting Data Stream Data and Clusterings
+#'
+#' Methods to plot data stream data and clusterings.
+#'
+#'
+#' @aliases plot plot.DSD plot.DSC
+#' @param x the DSD or DSC object to be plotted.
+#' @param dsd a DSD object to plot the data in the background.
+#' @param n number of plots taken from the dsd to plot.
+#' @param col,col_points,col_clusters colors used for plotting.
+#' @param weights the size of the symbols for micro- and macro-clusters
+#' represents its weight.
+#' @param scale range for the symbol sizes used.
+#' @param cex size factor for symbols.
+#' @param pch symbol type.
+#' @param method method used for plotting: "pairs" (pairs plot), "scatter"
+#' (scatter plot) or "pc" (plot first 2 principal components).
+#' @param dim an integer vector with the dimensions to plot. If \code{NULL}
+#' then for methods \code{"pairs"} and \code{"pc"} all dimensions are used and
+#' for \code{"scatter"} the first two dimensions are plotted.
+#' @param alpha alpha shading used to plot the points.
+#' @param type Plot micro clusters (\code{type="micro"}), macro clusters
+#' (\code{type="macro"}), both micro and macro clusters (\code{type="both"}),
+#' outliers(\code{type="outliers"}), or everything together
+#' (\code{type="all"}). \code{type="auto"} leaves to the class of dsc to
+#' decide.
+#' @param assignment logical; show assignment area of micro-clusters.
+#' @param \dots further arguments are passed on to plot or pairs in
+#' \pkg{graphics}.
+#' @author Michael Hahsler
+#' @seealso \code{\link{DSC}}, \code{\link{DSD}}
+#' @examples
+#'
+#' stream <- DSD_Gaussians(k=3, d=3)
+#'
+#' ## plot data
+#' plot(stream, n=500)
+#' plot(stream, method="pc", n=500)
+#' plot(stream, method="scatter", dim=c(1,3), n=500)
+#'
+#' ## create and plot micro-clusters
+#' dstream <- DSC_DStream(gridsize=0.1)
+#' update(dstream, stream, 500)
+#' plot(dstream)
+#'
+#' ## plot with data, projected on the first two principal components
+#' ## and dimensions 2 and 3
+#' plot(dstream, stream)
+#' plot(dstream, stream, method="pc")
+#' plot(dstream, stream, dim=c(2,3))
+#'
+#' ## plot micro and macro-clusters
+#' plot(dstream, stream, type="both")
 plot.DSC <- function(x, dsd = NULL, n = 500,
                      col_points=NULL,
                      col_clusters=c("red", "blue", "green"),
@@ -112,7 +238,7 @@ plot.DSC <- function(x, dsd = NULL, n = 500,
                      ...) {
 
   type <- match.arg(type)
-  if(type == "outliers" && !is(x, "DSC_Outlier"))
+  if(type == "outliers" && !is(x, "DSOutlier"))
     stop("The clusterer is not an outlier detector, cannot draw outliers")
 
   if(is.null(col_points)) col_points <- .points_col
@@ -156,7 +282,7 @@ plot.DSC <- function(x, dsd = NULL, n = 500,
     centers_mi <- get_centers(x, type="micro")
     centers_ma <- get_centers(x, type="macro")
     centers_out <- data.frame()
-    if(type=="all" && is(x, "DSC_Outlier")) centers_out <- get_outlier_positions(x)
+    if(type=="all" && is(x, "DSOutlier")) centers_out <- get_outlier_positions(x)
     k_mi <- nrow(centers_mi)
     k_ma <- nrow(centers_ma)
     k_out <- nrow(centers_out)
@@ -227,87 +353,3 @@ plot.DSC <- function(x, dsd = NULL, n = 500,
 
 }
 
-DSC_Outlier <- function(...) stop("DSC_Outlier is an abstract class and cannot be instantiated!")
-clean_outliers <- function(x, ...)
-  UseMethod("clean_outliers")
-clean_outliers.default <- function(x, ...) {
-  stop(gettextf("clean_outliers not implemented for class '%s'.", paste(class(x), collapse=", ")))
-}
-clean_outliers.DSC_Outlier <- function(x, ...) {
-  stop(gettextf("No clean outliers available for class '%s'.", paste(class(x), collapse=", ")))
-}
-get_outlier_positions <- function(x, ...)
-  UseMethod("get_outlier_positions")
-get_outlier_positions.default <- function(x, ...) {
-  stop(gettextf("get_outlier_positions not implemented for class '%s'.", paste(class(x), collapse=", ")))
-}
-get_outlier_positions.DSC_Outlier <- function(x, ...) {
-  stop(gettextf("No outlier getter method available for class '%s'.", paste(class(x), collapse=", ")))
-}
-recheck_outlier <- function(x, outlier_correlated_id, ...)
-  UseMethod("recheck_outlier")
-recheck_outlier.default <- function(x, outlier_correlated_id, ...) {
-  stop(gettextf("recheck_outlier not implemented for class '%s'.", paste(class(x), collapse=", ")))
-}
-recheck_outlier.DSC_Outlier <- function(x, outlier_correlated_id, ...) {
-  stop(gettextf("No outlier rechecking method available for class '%s'.", paste(class(x), collapse=", ")))
-}
-noutliers <- function(x, ...) UseMethod("noutliers")
-noutliers.default <- function(x, ...) {
-  stop(gettextf("noutliers not implemented for class '%s'.", paste(class(x), collapse=", ")))
-}
-noutliers.DSC_Outlier <- function(x, ...) {
-  nrow(get_outlier_positions(x))
-}
-print.DSC_Outlier <- function(x, ...) {
-  cat(.line_break(paste(x$description)))
-  cat("Class:", paste(class(x), collapse=", "), "\n")
-  if(!is(nc <- try(nclusters(x, type="micro"), silent=TRUE), "try-error"))
-    cat(paste('Number of micro-clusters:', nc, '\n'))
-  if(!is(nc <- try(nclusters(x, type="macro"), silent=TRUE), "try-error"))
-    cat(paste('Number of macro-clusters:', nc, '\n'))
-  if(!is(no <- try(noutliers(x), silent=TRUE), "try-error"))
-    cat(paste('Number of outliers:', no, '\n'))
-}
-get_assignment.DSC_Outlier <- function(x, points, type=c("auto", "micro", "macro"),
-                                       method=c("auto", "nn", "model"), outlier_threshold=0.05, ...) {
-
-  method <- match.arg(method)
-  if(method=="auto") method <- "nn"
-
-  if(method=="model") {
-    warning("method model not implemented! using Euclidean nearest neighbor instead!")
-    method <- "nn"
-  }
-
-  c1 <- get_centers(x, type=type, ...)
-  c2 <- get_outlier_positions(x, ...)
-  c <- rbind(c1, c2)
-
-  if(nrow(c)>0L) {
-    dist <- dist(points, c, method="Euclidean")
-    # Find the minimum distance and save the class
-    predict <- apply(dist, 1L, which.min)
-    outliers <- predict > nrow(c1)
-    outliers[apply(dist, 1L, min) > outlier_threshold] <- FALSE
-
-    to_noise <- predict > nrow(c1)
-    to_noise[apply(dist, 1L, min) <= outlier_threshold] <- FALSE
-    predict[to_noise] <- NA_integer_
-  } else {
-    warning("There are no clusters and outliers!")
-    predict <- rep(NA_integer_, nrow(points))
-    outliers <- rep(FALSE, nrow(points))
-  }
-
-  attr(predict, "method") <- method
-  attr(predict, "outliers") <- outliers
-
-  predict
-}
-
-DSC_SinglePass <- function(...) stop("DSC_SinglePass is an abstract class and cannot be instantiated!")
-get_assignment.DSC_SinglePass <- function(dsc, points, type=c("auto", "micro", "macro"),
-                                          method=c("auto", "nn", "model"), ...) {
-  stop(gettextf("No assignments and update available for class '%s'.", paste(class(dsc), collapse=", ")))
-}
