@@ -18,59 +18,67 @@
 
 
 
-#' Evolutionary Algorithm
-#'
-#' Reclustering using an evolutionary algorithm.
-#' This approach was designed for \code{evoStream} but can also be used for other micro-clustering algorithms.
-#' The evolutionary algorithm uses existing clustering solutions and creates small variations of them by combining and randomly modfiying them.
-#' The modified solutions can yield better partitions and thus can improve the clustering over time.
-#' The evolutionary algorithm is incremental, which allows to improve existing macro-clusters instead of recomputing them every time.
-#'
+
+
+#' Reclustering using an Evolutionary Algorithm
+#' 
+#' Macro Clusterer.
+#' 
+#' Reclustering using an evolutionary algorithm. This approach was designed for
+#' \code{evoStream} but can also be used for other micro-clustering algorithms.
+#' 
+#' The evolutionary algorithm uses existing clustering solutions and creates
+#' small variations of them by combining and randomly modfiying them. The
+#' modified solutions can yield better partitions and thus can improve the
+#' clustering over time. The evolutionary algorithm is incremental, which
+#' allows to improve existing macro-clusters instead of recomputing them every
+#' time.
+#' 
 #' @param k number of macro-clusters
 #' @param generations number of EA generations performed during reclustering
 #' @param crossoverRate cross-over rate for the evolutionary algorithm
 #' @param mutationRate mutation rate for the evolutionary algorithm
-#' @param populationSize number of solutions that the evolutionary algorithm maintains
-#'
+#' @param populationSize number of solutions that the evolutionary algorithm
+#' maintains
 #' @author Matthias Carnein \email{Matthias.Carnein@@uni-muenster.de}
-#'
-#' @references Carnein M. and Trautmann H. (2018), "evoStream - Evolutionary Stream Clustering Utilizing Idle Times", Big Data Research.
-#'
+#' @references Carnein M. and Trautmann H. (2018), "evoStream - Evolutionary
+#' Stream Clustering Utilizing Idle Times", Big Data Research.
 #' @examples
+#' 
 #' stream <- DSD_Memory(DSD_Gaussians(k = 3, d = 2), 1000)
-#'
+#' 
 #' ## online algorithm
 #' dbstream <- DSC_DBSTREAM(r=0.1)
-#'
-#' ## offline algorithm
-#' EA <- DSC_EA(k=3, generations=1000)
-#'
+#' 
+#' ## offline algorithm (note: we use a small number of generations
+#' ##                          to make this run faster.)
+#' EA <- DSC_EA(k=3, generations=100)
+#' 
 #' ## create pipeline and insert observations
 #' two <- DSC_TwoStage(dbstream, EA)
 #' update(two, stream, n=1000)
-#'
+#' 
 #' ## plot resut
 #' reset_stream(stream)
 #' plot(two, stream, type="both")
-#'
+#' 
 #' ## if we have time, evaluate additional generations. This can be
 #' ## called at any time, also between observations.
-#' two$macro_dsc$RObj$recluster(2000)
-#'
+#' two$macro_dsc$RObj$recluster(100)
+#' 
 #' ## plot improved result
 #' reset_stream(stream)
 #' plot(two, stream, type="both")
-#'
-#'
+#' 
+#' 
 #' ## alternatively: do not create twostage but apply directly
 #' reset_stream(stream)
 #' update(dbstream, stream, n = 1000)
 #' recluster(EA, dbstream)
 #' reset_stream(stream)
 #' plot(EA, stream)
-#'
-#'
-#' @export
+#' 
+#' @export DSC_EA
 DSC_EA <- function(k, generations=2000, crossoverRate=.8, mutationRate=.001, populationSize=100) {
 
 
@@ -143,7 +151,3 @@ EA_R$methods(
 )
 
 
-DSC_registry$set_entry(name = "DSC_EA",
-  DSC_Micro = FALSE, DSC_Macro = TRUE,
-  description = "EA - Reclustering using an evolutionary algorithm")
-
