@@ -10,7 +10,7 @@ stream <- DSD_Gaussians(k = 3, noise = 0.05)
 context("DSC_BIRCH")
 
 # create clusterer with r = 0.05
-BIRCH <- DSC_BIRCH(treshold = .1, branching = 8, maxLeaf = 20)
+BIRCH <- DSC_BIRCH(threshold = .1, branching = 8, maxLeaf = 20)
 update(BIRCH, stream, n = 10000)
 
 BIRCH
